# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic.v1 import BaseModel, Field, StrictStr, conlist

class GetAggregationUnitNameListResponse(BaseModel):
    """
    GetAggregationUnitNameListResponse
    https://developers.line.biz/en/reference/messaging-api/#get-name-list-of-units-used-this-month
    """
    custom_aggregation_units: conlist(StrictStr) = Field(..., alias="customAggregationUnits", description="An array of strings indicating the names of aggregation units used this month.")
    next: Optional[StrictStr] = Field(None, description="A continuation token to get the next array of unit names. Returned only when there are remaining aggregation units that weren't returned in customAggregationUnits in the original request.  ")

    __properties = ["customAggregationUnits", "next"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetAggregationUnitNameListResponse:
        """Create an instance of GetAggregationUnitNameListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetAggregationUnitNameListResponse:
        """Create an instance of GetAggregationUnitNameListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetAggregationUnitNameListResponse.parse_obj(obj)

        _obj = GetAggregationUnitNameListResponse.parse_obj({
            "custom_aggregation_units": obj.get("customAggregationUnits"),
            "next": obj.get("next")
        })
        return _obj




# coding: utf-8

"""
    Webhook Type Definition

    Webhook event definition of the LINE Messaging API  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, conlist
from linebot.v3.webhooks.models.action_result import ActionResult

class ScenarioResult(BaseModel):
    """
    ScenarioResult
    https://developers.line.biz/en/reference/messaging-api/#scenario-result-event
    """
    scenario_id: Optional[StrictStr] = Field(None, alias="scenarioId", description="Scenario ID executed")
    revision: Optional[StrictInt] = Field(None, description="Revision number of the scenario set containing the executed scenario")
    start_time: StrictInt = Field(..., alias="startTime", description="Timestamp for when execution of scenario action started (milliseconds, LINE app time)")
    end_time: StrictInt = Field(..., alias="endTime", description="Timestamp for when execution of scenario was completed (milliseconds, LINE app time)")
    result_code: StrictStr = Field(..., alias="resultCode", description="Scenario execution completion status")
    action_results: Optional[conlist(ActionResult)] = Field(None, alias="actionResults", description="Execution result of individual operations specified in action. Only included when things.result.resultCode is success.")
    ble_notification_payload: Optional[StrictStr] = Field(None, alias="bleNotificationPayload", description="Data contained in notification.")
    error_reason: Optional[StrictStr] = Field(None, alias="errorReason", description="Error reason.")

    __properties = ["scenarioId", "revision", "startTime", "endTime", "resultCode", "actionResults", "bleNotificationPayload", "errorReason"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ScenarioResult:
        """Create an instance of ScenarioResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic.v1 by calling `to_dict()` of each item in action_results (list)
        _items = []
        if self.action_results:
            for _item in self.action_results:
                if _item:
                    _items.append(_item.to_dict())
            _dict['actionResults'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ScenarioResult:
        """Create an instance of ScenarioResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ScenarioResult.parse_obj(obj)

        _obj = ScenarioResult.parse_obj({
            "scenario_id": obj.get("scenarioId"),
            "revision": obj.get("revision"),
            "start_time": obj.get("startTime"),
            "end_time": obj.get("endTime"),
            "result_code": obj.get("resultCode"),
            "action_results": [ActionResult.from_dict(_item) for _item in obj.get("actionResults")] if obj.get("actionResults") is not None else None,
            "ble_notification_payload": obj.get("bleNotificationPayload"),
            "error_reason": obj.get("errorReason")
        })
        return _obj




# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic.v1 import Field, StrictBool, StrictStr, validator
from linebot.v3.messaging.models.flex_component import FlexComponent

class FlexIcon(FlexComponent):
    """
    FlexIcon
    https://developers.line.biz/en/reference/messaging-api/#icon
    """
    url: StrictStr = Field(...)
    size: Optional[StrictStr] = None
    aspect_ratio: Optional[StrictStr] = Field(None, alias="aspectRatio")
    margin: Optional[StrictStr] = None
    position: Optional[StrictStr] = None
    offset_top: Optional[StrictStr] = Field(None, alias="offsetTop")
    offset_bottom: Optional[StrictStr] = Field(None, alias="offsetBottom")
    offset_start: Optional[StrictStr] = Field(None, alias="offsetStart")
    offset_end: Optional[StrictStr] = Field(None, alias="offsetEnd")
    scaling: Optional[StrictBool] = None
    type: str = "icon"

    __properties = ["type", "url", "size", "aspectRatio", "margin", "position", "offsetTop", "offsetBottom", "offsetStart", "offsetEnd", "scaling"]

    @validator('position')
    def position_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('relative', 'absolute'):
            raise ValueError("must be one of enum values ('relative', 'absolute')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FlexIcon:
        """Create an instance of FlexIcon from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FlexIcon:
        """Create an instance of FlexIcon from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FlexIcon.parse_obj(obj)

        _obj = FlexIcon.parse_obj({
            "type": obj.get("type"),
            "url": obj.get("url"),
            "size": obj.get("size"),
            "aspect_ratio": obj.get("aspectRatio"),
            "margin": obj.get("margin"),
            "position": obj.get("position"),
            "offset_top": obj.get("offsetTop"),
            "offset_bottom": obj.get("offsetBottom"),
            "offset_start": obj.get("offsetStart"),
            "offset_end": obj.get("offsetEnd"),
            "scaling": obj.get("scaling")
        })
        return _obj




# coding: utf-8

"""
    Webhook Type Definition

    Webhook event definition of the LINE Messaging API  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic.v1 import Field, StrictBool, StrictStr
from linebot.v3.webhooks.models.mentionee import Mentionee

class UserMentionee(Mentionee):
    """
    Mentioned target is user
    """
    user_id: Optional[StrictStr] = Field(None, alias="userId", description="User ID of the mentioned user. Only included if mention.mentions[].type is user and the user consents to the LINE Official Account obtaining their user profile information.")
    is_self: Optional[StrictBool] = Field(None, alias="isSelf", description="Whether the mentioned user is the bot that receives the webhook.")
    type: str = "user"

    __properties = ["type", "index", "length", "userId", "isSelf"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UserMentionee:
        """Create an instance of UserMentionee from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UserMentionee:
        """Create an instance of UserMentionee from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UserMentionee.parse_obj(obj)

        _obj = UserMentionee.parse_obj({
            "type": obj.get("type"),
            "index": obj.get("index"),
            "length": obj.get("length"),
            "user_id": obj.get("userId"),
            "is_self": obj.get("isSelf")
        })
        return _obj

